==> localbase-0.4.0.tgz: package/localbase/api/actions/delete.js <==
import * as localForage from "localforage"
import isSubset from '../../utils/isSubset'
import logger from "../../utils/logger";

export default function deleteIt() {

  return new Promise((resolve, reject) => {

    // delete database
    this.deleteDatabase = () => {
      indexedDB.deleteDatabase(this.dbName)
      resolve(
        this.success(
          `Database "${ this.dbName }" deleted.`
        )
      )
    }

    // delete collection
    this.deleteCollection = () => {

      if (this.collectionName == 'undefined') {
        reject(
          this.error(
            'No collection name passed into .collection() method.'
          )
        )
      }
      else {
        localForage.dropInstance().then(() => {
          resolve(
            this.success(
              `Collection "${ this.collectionName }" deleted.`
            )
          )
        }).catch(error => {
          reject(
            this.error(
              `Collection "${ this.collectionName }" could not be deleted.`
            )
          )
        })
      }

    }

    // delete document
    this.deleteDocument = () => {

      // delete document by criteria
      this.deleteDocumentByCriteria = () => {
        let keysForDeletion = []
        localForage.iterate((value, key) => {
          if (isSubset(value, this.docSelectionCriteria)) {
            keysForDeletion.push(key)
          }
        }).then(() => {
          if (keysForDeletion.length > 1) {
            logger.warn(`Multiple documents (${ keysForDeletion.length }) with ${ JSON.stringify(this.docSelectionCriteria) } found.`)
          }
        }).then(() => {
          keysForDeletion.forEach((key, index) => {
            localForage.removeItem(key).then(() => {
              if (index === (keysForDeletion.length - 1)) {
                resolve(
                  this.success(
                    `${ keysForDeletion.length } Document${ keysForDeletion.length > 1 ? 's' : '' } with ${ JSON.stringify(this.docSelectionCriteria) } deleted.`
                  )
                )
              }
            }).catch(err => {
              reject(
                this.error(
                  `Could not delete ${ keysForDeletion.length } Documents in ${ this.collectionName } Collection.`
                )
              )
            })
          })
        })
      }

      // delete document by key
      this.deleteDocumentByKey = () => {
        localForage.getItem(this.docSelectionCriteria).then(value => {
          if (value) {
            localForage.removeItem(this.docSelectionCriteria).then(() => {
              resolve(
                this.success(
                  `Document with key ${ JSON.stringify(this.docSelectionCriteria) } deleted.`
                )
              )
            }).catch(function(err) {
              reject(
                this.error(
                  `Document with key ${ JSON.stringify(this.docSelectionCriteria) } could not be deleted.`
                )
              )
            });
          }
          else {
            reject(
              this.error(
                `Document with key ${ JSON.stringify(this.docSelectionCriteria) } could not be deleted.`
              )
            )
          }
        });

      }

      if (this.docSelectionCriteria === 'undefined') {
        reject(
          this.error(
            `No criteria or key passed into doc() method.`
          )
        )
      }
      else if (typeof this.docSelectionCriteria == 'object') {
        return this.deleteDocumentByCriteria()
      }
      else {
        return this.deleteDocumentByKey()
      }
    }
    
    if (this.selectionLevel() == 'db') {
      return this.deleteDatabase()
    }
    else if (this.selectionLevel() == 'collection') {
      return this.deleteCollection()
    }
    else if (this.selectionLevel() == 'doc') {
      return this.deleteDocument()
    }

  })

}

==> localbase-0.6.3.tgz: package/localbase/api/actions/delete.js <==
import isSubset from '../../utils/isSubset'
import logger from "../../utils/logger"
import selectionLevel from '../../api-utils/selectionLevel'
import success from '../../api-utils/success'
import error from '../../api-utils/error'

export default function deleteIt() {

  return new Promise((resolve, reject) => {

    // delete database
    this.deleteDatabase = () => {
      indexedDB.deleteDatabase(this.dbName)
      resolve(
        success.call(
          this,
          `Database "${ this.dbName }" deleted.`
        )
      )
    }

    // delete collection
    this.deleteCollection = () => {

      if (this.collectionName == 'undefined') {
        reject(
          error.call(
            this,
            'No collection name passed into .collection() method.'
          )
        )
      }
      else {
        this.lf[this.collectionName].dropInstance().then(() => {
          resolve(
            success.call(
              this,
              `Collection "${ this.collectionName }" deleted.`
            )
          )
        }).catch(error => {
          reject(
            error.call(
              this,
              `Collection "${ this.collectionName }" could not be deleted.`
            )
          )
        })
      }

    }

    // delete document
    this.deleteDocument = () => {

      // delete document by criteria
      this.deleteDocumentByCriteria = () => {
        let keysForDeletion = []
        this.lf[this.collectionName].iterate((value, key) => {
          if (isSubset(value, this.docSelectionCriteria)) {
            keysForDeletion.push(key)
          }
        }).then(() => {
          if (keysForDeletion.length > 1) {
            logger.warn.call(this, `Multiple documents (${ keysForDeletion.length }) with ${ JSON.stringify(this.docSelectionCriteria) } found.`)
          }
        }).then(() => {
          keysForDeletion.forEach((key, index) => {
            this.lf[this.collectionName].removeItem(key).then(() => {
              if (index === (keysForDeletion.length - 1)) {
                resolve(
                  success.call(
                    this,
                    `${ keysForDeletion.length } Document${ keysForDeletion.length > 1 ? 's' : '' } with ${ JSON.stringify(this.docSelectionCriteria) } deleted.`
                  )
                )
              }
            }).catch(err => {
              reject(
                error.call(
                  this,
                  `Could not delete ${ keysForDeletion.length } Documents in ${ this.collectionName } Collection.`
                )
              )
            })
          })
        })
      }

      // delete document by key
      this.deleteDocumentByKey = () => {
        this.lf[this.collectionName].getItem(this.docSelectionCriteria).then(value => {
          if (value) {
            this.lf[this.collectionName].removeItem(this.docSelectionCriteria).then(() => {
              resolve(
                success.call(
                  this,
                  `Document with key ${ JSON.stringify(this.docSelectionCriteria) } deleted.`
                )
              )
            }).catch(function(err) {
              reject(
                error.call(
                  this,
                  `Document with key ${ JSON.stringify(this.docSelectionCriteria) } could not be deleted.`
                )
              )
            });
          }
          else {
            reject(
              error.call(
                this,
                `Document with key ${ JSON.stringify(this.docSelectionCriteria) } could not be deleted.`
              )
            )
          }
        });

      }

      if (this.docSelectionCriteria === 'undefined') {
        reject(
          error.call(
            this,
            `No criteria or key passed into doc() method.`
          )
        )
      }
      else if (typeof this.docSelectionCriteria == 'object') {
        return this.deleteDocumentByCriteria()
      }
      else {
        return this.deleteDocumentByKey()
      }
    }
    
    let currentSelectionLevel = selectionLevel.call(this)

    if (currentSelectionLevel == 'db') {
      return this.deleteDatabase()
    }
    else if (currentSelectionLevel == 'collection') {
      return this.deleteCollection()
    }
    else if (currentSelectionLevel == 'doc') {
      return this.deleteDocument()
    }

  })

}
